﻿using System.Windows;
using ThinkGeo.Core;

namespace LayerSample
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        LayerOverlay _layerOverlay = new LayerOverlay();
        private async void MapView_Loaded(object sender, RoutedEventArgs e)
        {
            MapView.MapUnit = GeographyUnit.Meter;

            var hotelsLayer = new InMemoryFeatureLayer();
            hotelsLayer.InternalFeatures.Add(new Feature("POINT (50 50)"));
            hotelsLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = PointStyle.CreateSimpleCircleStyle(GeoColors.Green, 8, GeoColors.Black, 1);
            hotelsLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            var parksLayer = new InMemoryFeatureLayer();
            parksLayer.InternalFeatures.Add(new Feature("POLYGON ((0 0, 100 0, 100 100, 0 100, 0 0))"));
            parksLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyle.CreateSimpleAreaStyle(GeoColors.Yellow, GeoColors.Black, 2);
            parksLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            _layerOverlay.Layers.Add(parksLayer);
            _layerOverlay.Layers.Add(hotelsLayer);

            MapView.Overlays.Add(_layerOverlay);

            MapView.CurrentExtent = new RectangleShape(0, 100, 100, 0);
            MapView.Refresh();
        }

        private async void MoveLayerDown_Click(object sender, RoutedEventArgs e)
        {
            // Move the layer down
            _layerOverlay.Layers.MoveDown(1);

            // Refresh the overlay to apply the changes
            _layerOverlay.Refresh();
        }
    }
}